@@ -1,9 +1,11 @@
 from .cdp import CDP
 from .request import CDPRequest
 from .response import CDPResponse
+from .cookie import CDPCookie
 
 __all__ = [
     'CDP',
     'CDPRequest',
     'CDPResponse',
+    'CDPCookie',
 ]
